@@ -4,9 +4,9 @@ from typing import (
     Optional,
     Literal,
 )
+import os
 
 from singular_client.documents import *
-from singular_client._utils import *
 from singular_client.arguments import *
 
 
@@ -24,10 +24,14 @@ class SingularAPI:
 
     key: str
 
-    def __init__(self, key: str):
+    def __init__(self, key: Optional[str]=None):
+        if not key:
+            key = os.environ.get("SINGULAR_API_KEY")
+            assert key, "No API key provided"
         self.key = key
 
         from singular_client import endpoints
+
         # Reporting
         self.combined_report = endpoints.CombinedReportEndpoint(self)
         self.network_report = endpoints.NetworkReportEndpoint(self)
@@ -95,11 +99,11 @@ class SingularAPI:
         else:
             params["api_key"] = self.key
 
-        print("new request:", f"{method.upper()} '{endpoint}'")
-        res = requests.request(method, url=url, params=params, headers=headers, data=data)
+        res = requests.request(
+            method, url=url, params=params, headers=headers, data=data
+        )
 
         assert (code := res.status_code) == 200, (code, res.text)
 
         # return UtilDict(res.json()).deep_uniform()
         return res.json()
-
