@@ -1,6 +1,7 @@
-from singular_client.endpoints._bases import _Endpoint
+from singular_client._bases import _Endpoint
 from singular_client.documents import *
 
+
 class GraphQL(_Endpoint[dict]):
     endpoint = "graphql/graphql"
     data_path = ["data"]
@@ -12,10 +13,7 @@ class GraphQL(_Endpoint[dict]):
         return super().request(
             data=query,
             headers={
-                'Accept': 'application/json',
-                'Content-Type': 'application/json',
-            }
+                "Accept": "application/json",
+                "Content-Type": "application/json",
+            },
         )
-
-
-
