@@ -1,8 +1,8 @@
-from singular_client.endpoints._bases import _Endpoint, ResponseDocList
+from singular_client._bases import _Endpoint, ResponseDocList
 from singular_client.documents import *
 from singular_client.arguments import *
-from singular_client._utils import *
 from typing import *
+from singular_client.utils import _convert_list_arg
 
 
 class DomainsEndpoint(_Endpoint[ResponseDocList[DomainDoc]]):
@@ -13,13 +13,16 @@ class DomainsEndpoint(_Endpoint[ResponseDocList[DomainDoc]]):
 
 # ==============================================================================
 
+
 class AppsEndpoint(_Endpoint[ResponseDocList[AppDoc]]):
     endpoint = "v1/singular_links/apps"
     data_path = ["available_apps"]
     res_type = ResponseDocList[AppDoc]
 
+
 # ==============================================================================
 
+
 class AllPartnersEndpoint(_Endpoint[ResponseDocList[PartnerDoc]]):
     endpoint = "v1/singular_links/all_partners"
     data_path = ["partners"]
@@ -27,11 +30,13 @@ class AllPartnersEndpoint(_Endpoint[ResponseDocList[PartnerDoc]]):
 
     def request(self, singular_partner_id: Optional[List[str]] = None):
         return super().request(
-            singular_partner_id=convert_list_arg(singular_partner_id)
+            singular_partner_id=_convert_list_arg(singular_partner_id)
         )
 
+
 # ==============================================================================
 
+
 class CreateLinkEndpoint(_Endpoint[CreateLinkDoc]):
     endpoint = "v1/singular_links/links"
     data_path = []
@@ -58,19 +63,29 @@ class CreateLinkEndpoint(_Endpoint[CreateLinkDoc]):
         click_reengagement_window: Optional[int] = None,
         enable_ctv: Optional[bool] = None,
     ):
-        assert android_redirection or ios_redirection, "Must provide at least one redirection"
+        assert (
+            android_redirection or ios_redirection
+        ), "Must provide at least one redirection"
 
         if click_reengagement_window:
-            assert enable_reengagement, "enable_reengagement must be True if click_reengagement_window is set"
+            assert (
+                enable_reengagement
+            ), "enable_reengagement must be True if click_reengagement_window is set"
 
         if click_deterministic_window:
-            assert 0 <= click_deterministic_window <= 30, "click_deterministic_window 0 to 30"
+            assert (
+                0 <= click_deterministic_window <= 30
+            ), "click_deterministic_window 0 to 30"
 
         if click_probabilistic_window:
-            assert 0 <= click_probabilistic_window <= 24, "click_probabilistic_window 0 to 24"
+            assert (
+                0 <= click_probabilistic_window <= 24
+            ), "click_probabilistic_window 0 to 24"
 
         if view_deterministic_window:
-            assert 0 <= view_deterministic_window <= 24, "view_deterministic_window 0 to 24"
+            assert (
+                0 <= view_deterministic_window <= 24
+            ), "view_deterministic_window 0 to 24"
 
         return super().request(
             data=dict(
@@ -93,8 +108,10 @@ class CreateLinkEndpoint(_Endpoint[CreateLinkDoc]):
             ),
         )
 
+
 # ==============================================================================
 
+
 class ViewLinksEndpoint(_Endpoint[ResponseDocList[LinkDoc]]):
     endpoint = "v1/singular_links/links"
     data_path = []
@@ -116,6 +133,7 @@ class ViewLinksEndpoint(_Endpoint[ResponseDocList[LinkDoc]]):
             tracking_link_id=tracking_link_id,
         )
 
+
 # ==============================================================================
 
 
@@ -130,9 +148,6 @@ class ConfiguredPartnersEndpoint(_Endpoint[ResponseDocList[PartnerAppDoc]]):
         partner_id: Optional[List[str]] = None,
     ):
         return super().request(
-            app_site_id=convert_list_arg(app_site_id),
-            partner_id=convert_list_arg(partner_id),
+            app_site_id=_convert_list_arg(app_site_id),
+            partner_id=_convert_list_arg(partner_id),
         )
-
-
-
