@@ -1,8 +1,9 @@
-from singular_client.endpoints._bases import _Endpoint, ResponseDocList
+from singular_client._bases import _Endpoint, ResponseDocList
 from singular_client.documents import *
-from singular_client._utils import *
+from singular_client.utils import _convert_list_arg
 from typing import *
 
+
 class AppsLegacyEndpoint(_Endpoint[ResponseDocList[AppLegacyDoc]]):
     endpoint = "v1/links/discover_apps"
     data_path = ["available_apps"]
@@ -73,19 +74,29 @@ class CreateCustomLinkLegacyEndpoint(_Endpoint[CustomLinkLegacyDoc]):
         reengagement_enabled: Optional[bool] = None,
         other_destination_fallback_url: Optional[str] = None,
     ):
-        assert ios_singular_app_id or android_singular_app_id, "Must provide at least one app id"
+        assert (
+            ios_singular_app_id or android_singular_app_id
+        ), "Must provide at least one app id"
 
         if ios_singular_app_id:
-            assert ios_destination_fallback_url, "Must provide ios_destination_fallback_url"
+            assert (
+                ios_destination_fallback_url
+            ), "Must provide ios_destination_fallback_url"
 
         if android_singular_app_id:
-            assert android_destination_fallback_url, "Must provide android_destination_fallback_url"
+            assert (
+                android_destination_fallback_url
+            ), "Must provide android_destination_fallback_url"
 
         if ios_deferred_deeplink_enabled:
-            assert ios_destination_deeplink_url, "Must provide ios_destination_deeplink_url"
+            assert (
+                ios_destination_deeplink_url
+            ), "Must provide ios_destination_deeplink_url"
 
         if android_deferred_deeplink_enabled:
-            assert android_destination_deeplink_url, "Must provide android_destination_deeplink_url"
+            assert (
+                android_destination_deeplink_url
+            ), "Must provide android_destination_deeplink_url"
 
         return super().request(
             data=dict(
@@ -119,9 +130,9 @@ class ViewLinksLegacyEndpoint(_Endpoint[ResponseDocList[LinkLegacyDoc]]):
         include_archived_links: bool = False,
     ):
         return super().request(
-            singular_app_ids=convert_list_arg(singular_app_ids),
-            singular_partner_ids=convert_list_arg(singular_partner_ids),
-            tracking_link_ids=convert_list_arg(tracking_link_ids),
+            singular_app_ids=_convert_list_arg(singular_app_ids),
+            singular_partner_ids=_convert_list_arg(singular_partner_ids),
+            tracking_link_ids=_convert_list_arg(tracking_link_ids),
             include_archived_links=include_archived_links,
         )
 
@@ -139,8 +150,8 @@ class ViewCustomLinksLegacyEndpoint(_Endpoint[ResponseDocList[CustomLinkLegacyDo
         include_archived_links: bool = False,
     ):
         return super().request(
-            singular_app_ids=convert_list_arg(singular_app_ids),
+            singular_app_ids=_convert_list_arg(singular_app_ids),
             custom_source_name=custom_source_name,
-            tracking_link_ids=convert_list_arg(tracking_link_ids),
+            tracking_link_ids=_convert_list_arg(tracking_link_ids),
             include_archived_links=include_archived_links,
         )
