@@ -1,8 +1,9 @@
-from singular_client.endpoints._bases import _Endpoint, ResponseDocList
+from singular_client._bases import _Endpoint, ResponseDocList
 from singular_client.documents import *
 from singular_client.arguments import *
 from typing import *
-from singular_client._utils import *
+from singular_client.utils import _convert_list_arg
+
 
 class AdMonetizationEndpoint(_Endpoint[ResponseDocList[AdMonetizationDoc]]):
     endpoint = "v2.0/admonetization/reporting"
@@ -26,13 +27,11 @@ class AdMonetizationEndpoint(_Endpoint[ResponseDocList[AdMonetizationDoc]]):
             start_date=start_date,
             end_date=end_date or start_date,
             time_breakdown=time_breakdown,
-            dimensions=convert_list_arg(dimensions, AD_MON_DIMENSIONS),
-            metrics=convert_list_arg(metrics, AD_MON_METRICS),
-            app=convert_list_arg(app),
-            source=convert_list_arg(source),
+            dimensions=_convert_list_arg(dimensions, AD_MON_DIMENSIONS),
+            metrics=_convert_list_arg(metrics, AD_MON_METRICS),
+            app=_convert_list_arg(app),
+            source=_convert_list_arg(source),
             filters=filters,
             format=format,
             country_code_format=country_code_format,
         )
-
-
