@@ -1,8 +1,7 @@
-from singular_client.endpoints._bases import _Endpoint, ResponseDocList
+from singular_client._bases import _Endpoint, ResponseDocList
 from singular_client.documents import *
 from singular_client.arguments import *
-from singular_client._utils import convert_list_arg
-import pandas as pd
+from singular_client.utils import _convert_list_arg
 import json
 import time
 import requests
@@ -18,9 +17,10 @@ class ReportStatusResponse:
     cached_download: Optional[Union[requests.Response, "pd.DataFrame"]]
     status: ReportStatusDoc
     failed = property(lambda x: x.status["status"] == "FAILED")
-    done = property(lambda x: x.status["status"] == "FAILED")
+    done = property(lambda x: x.status["status"] == "DONE")
     queued = property(lambda x: x.status["status"] == "QUEUED")
     started = property(lambda x: x.status["status"] == "STARTED")
+    url = property(lambda x: x.status["download_url"])
 
     def __init__(self, doc: dict):
         self.status = cast(ReportStatusDoc, doc)
@@ -85,10 +85,10 @@ class ReportStatusEndpoint(_Endpoint[ReportStatusResponse]):
         return super().request(report_id=report_id)
 
 
-class FiltersEndpoint(_Endpoint[ResponseDocList[FilterDoc]]):
+class FiltersEndpoint(_Endpoint[ResponseDocList[NameDocValues]]):
     endpoint = "v2.0/reporting/filters"
     data_path = ["value", "dimensions"]
-    res_type = ResponseDocList[FilterDoc]
+    res_type = ResponseDocList[NameDocValues]
 
 
 class CohortMetricsEndpoint(_Endpoint[CohortMetricsDoc]):
@@ -197,21 +197,21 @@ class _AggReportEndpoint(
         display_alignment: bool = False,
         display_unenriched: bool = False,
     ):
-        dimensions_str = convert_list_arg(dimensions, self.available_dimensions)
+        dimensions_str = _convert_list_arg(dimensions, self.available_dimensions)
         if custom_dimensions:
-            dimensions_str += convert_list_arg(custom_dimensions)
+            dimensions_str += _convert_list_arg(custom_dimensions)
         report_id = super().request(
             data=dict(
                 start_date=start_date,
                 end_date=end_date or start_date,
                 time_breakdown=time_breakdown,
                 dimensions=dimensions_str,
-                metrics=convert_list_arg(metrics, self.available_metrics),
-                custom_dimensions=convert_list_arg(custom_dimensions),
-                cohort_metrics=convert_list_arg(cohort_metrics),
-                cohort_periods=convert_list_arg(cohort_periods),
-                app=convert_list_arg(app),
-                source=convert_list_arg(source),
+                metrics=_convert_list_arg(metrics, self.available_metrics),
+                custom_dimensions=_convert_list_arg(custom_dimensions),
+                cohort_metrics=_convert_list_arg(cohort_metrics),
+                cohort_periods=_convert_list_arg(cohort_periods),
+                app=_convert_list_arg(app),
+                source=_convert_list_arg(source),
                 filters=filters,
                 format=format,
                 country_code_format=country_code_format,
