@@ -1,9 +1,9 @@
-from singular_client.endpoints._bases import _Endpoint, ResponseDocList
+from singular_client._bases import _Endpoint, ResponseDocList
 from singular_client.documents import *
 from singular_client.arguments import *
 from singular_client.endpoints.reporting import CreateReportResponse
 from typing import *
-from singular_client._utils import *
+from singular_client.utils import _convert_list_arg
 
 
 class SkanEventsEndpoint(_Endpoint[ResponseDocList[NameDoc]]):
@@ -12,10 +12,11 @@ class SkanEventsEndpoint(_Endpoint[ResponseDocList[NameDoc]]):
     res_type = ResponseDocList[NameDoc]
 
 
-
 class SkanRawReportEndpoint(_Endpoint[CreateReportResponse]):
     endpoint = "v2.0/create_async_skadnetwork_raw_report"
     data_path = ["value", "report_id"]
+    available_dimensions = SKAN_RAW_DIMENSIONS
+    available_metrics = SKAN_RAW_METRICS
     res_type = CreateReportResponse
     returns_collection = False
     method = "POST"
@@ -40,10 +41,10 @@ class SkanRawReportEndpoint(_Endpoint[CreateReportResponse]):
                 end_date=end_date or start_date,
                 time_breakdown=time_breakdown,
                 skadnetwork_date_type=skadnetwork_date_type,
-                dimensions=convert_list_arg(dimensions, SKAN_RAW_DIMENSIONS),
-                metrics=convert_list_arg(metrics, SKAN_RAW_METRICS),
-                app=convert_list_arg(app),
-                source=convert_list_arg(source),
+                dimensions=_convert_list_arg(dimensions, self.available_dimensions),
+                metrics=_convert_list_arg(metrics, self.available_metrics),
+                app=_convert_list_arg(app),
+                source=_convert_list_arg(source),
                 filters=filters,
                 format=format,
                 country_code_format=country_code_format,
@@ -57,6 +58,8 @@ class SkanReportEndpoint(_Endpoint[CreateReportResponse]):
     endpoint = "v2.0/create_async_skadnetwork_report"
     data_path = ["value", "report_id"]
     res_type = CreateReportResponse
+    available_dimensions = SKAN_DIMENSIONS
+    available_metrics = SKAN_METRICS
     returns_collection = False
     method = "POST"
 
@@ -77,9 +80,9 @@ class SkanReportEndpoint(_Endpoint[CreateReportResponse]):
                 end_date=end_date or start_date,
                 time_breakdown=time_breakdown,
                 skadnetwork_date_type=skadnetwork_date_type,
-                dimensions=convert_list_arg(dimensions, SKAN_DIMENSIONS),
-                metrics=convert_list_arg(metrics, SKAN_METRICS),
-                skan_events=convert_list_arg(skan_events),
+                dimensions=_convert_list_arg(dimensions, self.available_dimensions),
+                metrics=_convert_list_arg(metrics, self.available_metrics),
+                skan_events=_convert_list_arg(skan_events),
                 format=format,
             ),
         )
